class AddAdminRoleAndPermissions < ActiveRecord::Migration[8.0]
  def up
    # Create admin role
    admin_role = Role.create!(name: 'admin', description: 'Can manage users and assign roles')

    # Create user management permissions
    manage_users = Permission.create!(name: 'manage_users', description: 'Can create, edit, and delete users')
    assign_roles = Permission.create!(name: 'assign_roles', description: 'Can assign roles to users')

    # Associate permissions with admin role
    admin_role.permissions << manage_users
    admin_role.permissions << assign_roles

    # Also give admin all the permissions of events_admin and shift_coordinator
    events_admin_role = Role.find_by(name: 'events_admin')
    if events_admin_role
      events_admin_role.permissions.each do |permission|
        admin_role.permissions << permission unless admin_role.permissions.include?(permission)
      end
    end

    shift_coordinator_role = Role.find_by(name: 'shift_coordinator')
    if shift_coordinator_role
      shift_coordinator_role.permissions.each do |permission|
        admin_role.permissions << permission unless admin_role.permissions.include?(permission)
      end
    end
  end

  def down
    # Find and remove the admin role
    admin_role = Role.find_by(name: 'admin')
    if admin_role
      # First remove all role_permissions associations
      admin_role.role_permissions.destroy_all
      # Then delete the role itself
      admin_role.destroy
    end

    # Delete the permissions
    Permission.where(name: [ 'manage_users', 'assign_roles' ]).destroy_all
  end
end
